@@ -1,19 +1,28 @@
 """Utilities for launching kernels"""
-
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
-
 import os
 import sys
-from subprocess import Popen, PIPE
+from subprocess import PIPE
+from subprocess import Popen
+from typing import Dict
+from typing import List
+from typing import Optional
 
-from ipython_genutils.encoding import getdefaultencoding
-from traitlets.log import get_logger
+from traitlets.log import get_logger  # type: ignore
 
 
-def launch_kernel(cmd, stdin=None, stdout=None, stderr=None, env=None,
-                  independent=False, cwd=None, **kw):
-    """ Launches a localhost kernel, binding to the specified ports.
+def launch_kernel(
+    cmd: List[str],
+    stdin: Optional[int] = None,
+    stdout: Optional[int] = None,
+    stderr: Optional[int] = None,
+    env: Optional[Dict[str, str]] = None,
+    independent: bool = False,
+    cwd: Optional[str] = None,
+    **kw,
+) -> Popen:
+    """Launches a localhost kernel, binding to the specified ports.
 
     Parameters
     ----------
@@ -57,9 +66,9 @@ def launch_kernel(cmd, stdin=None, stdout=None, stderr=None, env=None,
 
     # If this process in running on pythonw, we know that stdin, stdout, and
     # stderr are all invalid.
-    redirect_out = sys.executable.endswith('pythonw.exe')
+    redirect_out = sys.executable.endswith("pythonw.exe")
     if redirect_out:
-        blackhole = open(os.devnull, 'w')
+        blackhole = open(os.devnull, "w")
         _stdout = blackhole if stdout is None else stdout
         _stderr = blackhole if stderr is None else stderr
     else:
@@ -67,7 +76,6 @@ def launch_kernel(cmd, stdin=None, stdout=None, stderr=None, env=None,
 
     env = env if (env is not None) else os.environ.copy()
 
-    encoding = getdefaultencoding(prefer_stream=False)
     kwargs = kw.copy()
     main_args = dict(
         stdin=_stdin,
@@ -79,11 +87,12 @@ def launch_kernel(cmd, stdin=None, stdout=None, stderr=None, env=None,
     kwargs.update(main_args)
 
     # Spawn a kernel.
-    if sys.platform == 'win32':
+    if sys.platform == "win32":
         if cwd:
-            kwargs['cwd'] = cwd
+            kwargs["cwd"] = cwd
 
         from .win_interrupt import create_interrupt_event
+
         # Create a Win32 event for interrupting the kernel
         # and store it in an environment variable.
         interrupt_event = create_interrupt_event()
@@ -92,70 +101,86 @@ def launch_kernel(cmd, stdin=None, stdout=None, stderr=None, env=None,
         env["IPY_INTERRUPT_EVENT"] = env["JPY_INTERRUPT_EVENT"]
 
         try:
-            from _winapi import DuplicateHandle, GetCurrentProcess, \
-                DUPLICATE_SAME_ACCESS, CREATE_NEW_PROCESS_GROUP
-        except:
-            from _subprocess import DuplicateHandle, GetCurrentProcess, \
-                DUPLICATE_SAME_ACCESS, CREATE_NEW_PROCESS_GROUP
+            from _winapi import (
+                CREATE_NEW_PROCESS_GROUP,
+                DUPLICATE_SAME_ACCESS,
+                DuplicateHandle,
+                GetCurrentProcess,
+            )
+        except:  # noqa
+            from _subprocess import (  # type: ignore
+                GetCurrentProcess,
+                CREATE_NEW_PROCESS_GROUP,
+                DUPLICATE_SAME_ACCESS,
+                DuplicateHandle,
+            )
 
         # create a handle on the parent to be inherited
         if independent:
-            kwargs['creationflags'] = CREATE_NEW_PROCESS_GROUP
+            kwargs["creationflags"] = CREATE_NEW_PROCESS_GROUP
         else:
             pid = GetCurrentProcess()
-            handle = DuplicateHandle(pid, pid, pid, 0,
-                                     True, # Inheritable by new processes.
-                                     DUPLICATE_SAME_ACCESS)
-            env['JPY_PARENT_PID'] = str(int(handle))
+            handle = DuplicateHandle(
+                pid,
+                pid,
+                pid,
+                0,
+                True,
+                DUPLICATE_SAME_ACCESS,  # Inheritable by new processes.
+            )
+            env["JPY_PARENT_PID"] = str(int(handle))
 
         # Prevent creating new console window on pythonw
         if redirect_out:
-            kwargs['creationflags'] = kwargs.setdefault('creationflags', 0) | 0x08000000 # CREATE_NO_WINDOW
+            kwargs["creationflags"] = (
+                kwargs.setdefault("creationflags", 0) | 0x08000000
+            )  # CREATE_NO_WINDOW
 
         # Avoid closing the above parent and interrupt handles.
         # close_fds is True by default on Python >=3.7
         # or when no stream is captured on Python <3.7
         # (we always capture stdin, so this is already False by default on <3.7)
-        kwargs['close_fds'] = False
+        kwargs["close_fds"] = False
     else:
         # Create a new session.
         # This makes it easier to interrupt the kernel,
         # because we want to interrupt the whole process group.
         # We don't use setpgrp, which is known to cause problems for kernels starting
         # certain interactive subprocesses, such as bash -i.
-        kwargs['start_new_session'] = True
+        kwargs["start_new_session"] = True
         if not independent:
-            env['JPY_PARENT_PID'] = str(os.getpid())
+            env["JPY_PARENT_PID"] = str(os.getpid())
 
     try:
         # Allow to use ~/ in the command or its arguments
-        cmd = list(map(os.path.expanduser, cmd))
-
+        cmd = [os.path.expanduser(s) for s in cmd]
         proc = Popen(cmd, **kwargs)
-    except Exception as exc:
-        msg = (
-            "Failed to run command:\n{}\n"
-            "    PATH={!r}\n"
-            "    with kwargs:\n{!r}\n"
-        )
-        # exclude environment variables,
-        # which may contain access tokens and the like.
-        without_env = {key:value for key, value in kwargs.items() if key != 'env'}
-        msg = msg.format(cmd, env.get('PATH', os.defpath), without_env)
-        get_logger().error(msg)
-        raise
+    except Exception as ex:
+        try:
+            msg = "Failed to run command:\n{}\n" "    PATH={!r}\n" "    with kwargs:\n{!r}\n"
+            # exclude environment variables,
+            # which may contain access tokens and the like.
+            without_env = {key: value for key, value in kwargs.items() if key != "env"}
+            msg = msg.format(cmd, env.get("PATH", os.defpath), without_env)
+            get_logger().error(msg)
+        except Exception as ex2:  # Don't let a formatting/logger issue lead to the wrong exception
+            print(f"Failed to run command: '{cmd}' due to exception: {ex}")
+            print(f"The following exception occurred handling the previous failure: {ex2}")
+        raise ex
 
-    if sys.platform == 'win32':
+    if sys.platform == "win32":
         # Attach the interrupt event to the Popen objet so it can be used later.
-        proc.win32_interrupt_event = interrupt_event
+        proc.win32_interrupt_event = interrupt_event  # type: ignore
 
     # Clean up pipes created to work around Popen bug.
     if redirect_in:
         if stdin is None:
+            assert proc.stdin is not None
             proc.stdin.close()
 
     return proc
 
+
 __all__ = [
-    'launch_kernel',
+    "launch_kernel",
 ]
